pub struct AABB<P>where
P: Point,{ /* private fields */ }Expand description
Axis-aligned bounding box for spatial queries. An n-dimensional axis aligned bounding box (AABB).
An object’s AABB is the smallest box totally encompassing an object while being aligned to the current coordinate system. Although these structures are commonly called bounding boxes, they exist in any dimension.
Note that AABBs cannot be inserted into r-trees. Use the Rectangle struct for this purpose.
Type arguments
P: The struct is generic over which point type is used. Using an n-dimensional point
type will result in an n-dimensional bounding box.
Implementations
Sourceimpl<P> AABB<P>where
P: Point,
impl<P> AABB<P>where
P: Point,
Sourcepub fn from_point(p: P) -> AABB<P>
pub fn from_point(p: P) -> AABB<P>
Returns the AABB encompassing a single point.
Sourcepub fn lower(&self) -> P
pub fn lower(&self) -> P
Returns the AABB’s lower corner.
This is the point contained within the AABB with the smallest coordinate value in each dimension.
Sourcepub fn upper(&self) -> P
pub fn upper(&self) -> P
Returns the AABB’s upper corner.
This is the point contained within the AABB with the largest coordinate value in each dimension.
Sourcepub fn from_corners(p1: P, p2: P) -> AABB<P>
pub fn from_corners(p1: P, p2: P) -> AABB<P>
Creates a new AABB encompassing two points.
Sourcepub fn from_points<'a, I>(i: I) -> AABB<P>where
I: IntoIterator<Item = &'a P> + 'a,
P: 'a,
pub fn from_points<'a, I>(i: I) -> AABB<P>where
I: IntoIterator<Item = &'a P> + 'a,
P: 'a,
Creates a new AABB encompassing a collection of points.