Module grouping

Module grouping 

Route grouping algorithms.

This module provides functionality to group similar routes together using spatial indexing and Union-Find for efficient grouping.

Functions

check_middle_points_match
Check that the middle portions of two routes also match.
distance_ratio_ok
Check if two distances are within acceptable ratio (50%).
group_incremental
Incremental grouping: efficiently add new signatures to existing groups.
group_signatures
Group similar routes together.
group_signatures_parallel
Group signatures using parallel processing.
group_signatures_parallel_with_matches
Group signatures in parallel and capture match info for each activity.
group_signatures_with_matches
Group similar routes together and capture match info for each activity.
should_group_routes
Check if two routes should be GROUPED into the same route.