Route grouping algorithms.
This module provides functionality to group similar routes together using spatial indexing and Union-Find for efficient grouping.
Functions
- check_
middle_ points_ match - Check that the middle portions of two routes also match.
- distance_
ratio_ ok - Check if two distances are within acceptable ratio (50%).
- group_
incremental - Incremental grouping: efficiently add new signatures to existing groups.
- group_
signatures - Group similar routes together.
- group_
signatures_ parallel - Group signatures using parallel processing.
- group_
signatures_ parallel_ with_ matches - Group signatures in parallel and capture match info for each activity.
- group_
signatures_ with_ matches - Group similar routes together and capture match info for each activity.
- should_
group_ routes - Check if two routes should be GROUPED into the same route.